pub enum EventOrInitial<T> {
Event(T),
InitialMessage(Message),
}Available on crate feature
event-stream only.Expand description
Wrapper for event stream items that may include an initial-request message. This is used internally to allow initial messages to flow through the signing pipeline.